package com.persagy.apm.alarmservice.group.alarmrule.controller;

import com.persagy.apm.alarmservice.group.alarmrule.service.IGroupAlarmRuleService;

import com.persagy.apm.energyalarmstarter.alarmdata.feign.DmpResult;
import com.persagy.apm.energyalarmstarter.alarmdata.model.dto.common.QueryAlarmConfigDTO;
import com.persagy.apm.energyalarmstarter.alarmdata.model.vo.AlarmConfigItem;
import com.persagy.apm.energyalarmstarter.alarmdata.service.AlarmConfigServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.persagy.apm.alarmservice.group.alarmrule.model.*;
import com.persagy.apm.alarmservice.group.alarmrule.model.vo.*;
import com.persagy.apm.alarmservice.group.alarmrule.model.dto.*;
import com.persagy.apm.common.response.*;
import com.persagy.apm.common.utils.ResultHelper;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import javax.validation.Valid;
import java.util.List;

/**
 * 集团报警规则控制层
 * @author lixing
 * @version V1.0 2021-09-08 22:35:45
 */
@Api(tags = "集团报警规则") 
@Validated
@RestController
@RequestMapping("groupAlarmRules")
public class GroupAlarmRuleController {
    @Autowired
    private IGroupAlarmRuleService groupAlarmRuleService;

	@ApiOperation(value = "创建集团报警规则")
	@PostMapping("/create")
	public CommonResult<ApmResponseUpsertVO> createGroupAlarmRule(
	        @Valid @RequestBody AddGroupAlarmRuleDTO addGroupAlarmRuleDTO) {
        String id = groupAlarmRuleService.createGroupAlarmRule(addGroupAlarmRuleDTO);
        return ResultHelper.single(new ApmResponseUpsertVO(id));
	}
	
	@ApiOperation(value = "集团报警规则详情")
    @PostMapping("/get")
    public CommonResult<GroupAlarmRuleItemVO> queryGroupAlarmRuleDetail(
            @Valid @RequestBody QueryGroupAlarmRuleDetailDTO queryGroupAlarmRuleDetailDTO) {
        GroupAlarmRule groupAlarmRule = groupAlarmRuleService.queryGroupAlarmRuleDetail(queryGroupAlarmRuleDetailDTO.getId());
        GroupAlarmRuleItemVO groupAlarmRuleItemVO = ConvertGroupAlarmRuleTool.INSTANCE.convert2ResponseItemDTO(groupAlarmRule);
        return ResultHelper.single(groupAlarmRuleItemVO);
    }


    @ApiOperation(value = "更新集团报警规则")
    @PostMapping("/update")
    public CommonResult<ApmResponseUpsertVO> updateGroupAlarmRule(
            @Valid @RequestBody UpdateGroupAlarmRuleDTO updateGroupAlarmRuleDTO) {
        groupAlarmRuleService.updateGroupAlarmRule(updateGroupAlarmRuleDTO);
        return ResultHelper.single(new ApmResponseUpsertVO(updateGroupAlarmRuleDTO.getId()));
    }


    @ApiOperation(value = "删除集团报警规则")
    @PostMapping("/delete")
    public CommonResult deleteGroupAlarmRule(
            @RequestBody @Valid DeleteGroupAlarmRuleDTO deleteGroupAlarmRuleDTO) {
        groupAlarmRuleService.deleteGroupAlarmRule(deleteGroupAlarmRuleDTO.getId());
        return ResultHelper.success();
    }


    @ApiOperation(value = "集团报警规则列表")
    @PostMapping("/query")
    public CommonResult<PageList<GroupAlarmRuleListItemVO>> queryGroupAlarmRule(
            @Valid @RequestBody QueryGroupAlarmRuleDTO queryGroupAlarmRuleDTO) {
        List<GroupAlarmRule> groupAlarmRuleList = groupAlarmRuleService.queryGroupAlarmRuleList(queryGroupAlarmRuleDTO);
        List<GroupAlarmRuleListItemVO> resultList = ConvertGroupAlarmRuleTool.INSTANCE.convert2List(groupAlarmRuleList);
        return ResultHelper.multi(resultList);
    }
    
    //@ApiOperation(value = "集团报警规则列表, 分页查询")
    //@PostMapping("/query")
    //public CommonResult<PageList<GroupAlarmRuleListItemVO>> queryGroupAlarmRule(
    //        @Valid @RequestBody PageQueryGroupAlarmRuleDTO pageQueryGroupAlarmRuleDTO) {
    //    IPage<GroupAlarmRule> pagedList = groupAlarmRuleService.pageQueryGroupAlarmRule(pageQueryGroupAlarmRuleDTO);
    //    IPage<GroupAlarmRuleListItemVO> pagedResultList = pagedList.convert(item -> {
    //        try {
    //           return ConvertGroupAlarmRuleTool.INSTANCE.convert2ResponseListItemDTO(item);
    //        } catch (Exception e) {
    //            throw new IllegalArgumentException("分页查询，GroupAlarmRule实体类转换为列表对象发生异常", e);
    //        }
    //    });
    //    return ResultHelper.multi(pagedResultList);
    //}

    @Autowired
    AlarmConfigServiceImpl alarmConfigService;

    @ApiOperation(value = "")
    @PostMapping("/test")
    public void test() throws Exception{
        QueryAlarmConfigDTO queryAlarmConfigDTO = new QueryAlarmConfigDTO();
        DmpResult<List<AlarmConfigItem>> query = alarmConfigService.query(queryAlarmConfigDTO);
        System.out.println(query);
    }

}

